'use strict';

Object.defineProperty(exports, "__esModule", {
   value: true
});

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }(); /*jshint esversion: 6 */
/*
printer.js
==========
A module to control GoDex printer.
*/


var _serialport = require('serialport');

var _serialport2 = _interopRequireDefault(_serialport);

var _events = require('events');

var _events2 = _interopRequireDefault(_events);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

var eventEmitter = new _events2.default.EventEmitter();

var Printer = function () {

   //config : {port: 'COM2', baud: '9600'}
   function Printer() {
      var _ref = arguments.length <= 0 || arguments[0] === undefined ? {} : arguments[0];

      var _ref$port = _ref.port;
      var port = _ref$port === undefined ? null : _ref$port;

      _classCallCheck(this, Printer);

      this.port = port;
      this.baud = 9600;
      // Printer status
      this.status = { '00': 'Ready', '01': 'Media Empty or Media Jam', '02': 'Media Empty or Media Jam', '03': 'Ribbon Empty',
         '04': 'Door Open', '05': 'Rewinder Full', '06': 'File System Full', '07': 'Filename Not Found',
         '08': 'Duplicate Name', '09': 'Syntax Error', '10': 'Cutter Jam', '11': 'Extended Memory Not Found', '20': 'Pause', '21': 'In Setting Mode', '22': 'In Keyboard Mode', '50': 'Printer is Printing', '60': 'Data in Process' };

      this.isPrinting = false;
      this.queue = [];
      this.sp = null;
   }

   // Set serial port


   _createClass(Printer, [{
      key: 'setPort',
      value: function setPort(port) {
         this.port = port;
      }
   }, {
      key: 'start',
      value: function start() {
         this.sp = new _serialport2.default(this.port, { baudrate: this.baud, parser: _serialport2.default.parsers.readline('\n') }, function (err) {
            if (err) console.error(err);else {
               this.nextPrintTask();
            }
         }.bind(this));
      }
   }, {
      key: 'stop',
      value: function stop() {
         if (this.sp && this.sp.isOpen()) this.sp.close();
      }

      // Get list of serial ports

   }, {
      key: 'getPorts',
      value: function getPorts(callback) {
         var portList = [];
         _serialport2.default.list(function (err, ports) {
            if (ports.length > 0) portList = ports;
            callback(portList);
         });
      }

      // Push a print task to queue

   }, {
      key: 'addPrintTask',
      value: function addPrintTask(task) {
         this.queue.push(task);
         this.nextPrintTask();
      }

      // Run next task

   }, {
      key: 'nextPrintTask',
      value: function nextPrintTask() {
         if (this.sp && this.sp.isOpen()) {
            // If not printing
            if (!this.isPrinting) {
               // If task leftover in queue
               if (this.queue.length > 0) {
                  this.print(this.queue.splice(0, 1)[0], function (err, message) {
                     if (err) console.error(message);
                  }.bind(this));
               }
            }
         }
      }

      // Test print

   }, {
      key: 'testPrint',
      value: function testPrint(callback) {
         this.print('~V\n', callback);
      }

      // Test printer head

   }, {
      key: 'testPrintHead',
      value: function testPrintHead(callback) {
         this.print('~T\n', callback);
      }

      // Get printer status

   }, {
      key: 'getPrinterStatus',
      value: function getPrinterStatus(callback) {
         var sp = new _serialport2.default(this.port, { baudrate: 9600, parser: _serialport2.default.parsers.readline('\n') }, function (err) {
            if (err) {
               callback({ error: -1, message: "Error opening COM port. Please check if printer is connected." });
            } else {
               // On serial data received
               sp.on('data', function (data) {
                  var d = data.replace('\r', '');
                  callback(this.status[d]);
                  sp.close();
               }.bind(this));
               // Write to serial
               sp.write("^XSET,IMMEDIATE,1\n~S,CHECK\n", function (err, results) {});
            }
         }.bind(this));
      }
   }, {
      key: 'print',
      value: function print(command, callback) {
         if (this.sp.isOpen()) {
            if (!this.isPrinting) {
               this.isPrinting = true;
               this.sp.write(command, function () {
                  this.sp.drain(function () {
                     this.isPrinting = false;
                     this.nextPrintTask();
                     callback();
                  }.bind(this));
               }.bind(this));
            }
         } else {
            callback(-1, "No port open");
         }
      }
   }]);

   return Printer;
}();

exports.default = Printer;