'use strict';

Object.defineProperty(exports, "__esModule", {
   value: true
});

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

var _get = function get(object, property, receiver) { if (object === null) object = Function.prototype; var desc = Object.getOwnPropertyDescriptor(object, property); if (desc === undefined) { var parent = Object.getPrototypeOf(object); if (parent === null) { return undefined; } else { return get(parent, property, receiver); } } else if ("value" in desc) { return desc.value; } else { var getter = desc.get; if (getter === undefined) { return undefined; } return getter.call(receiver); } };

var _label = require('./label');

var _label2 = _interopRequireDefault(_label);

var _fs = require('fs');

var _fs2 = _interopRequireDefault(_fs);

var _xmlParser = require('xml-parser');

var _xmlParser2 = _interopRequireDefault(_xmlParser);

var _underscore = require('underscore');

var _underscore2 = _interopRequireDefault(_underscore);

var _moment = require('moment');

var _moment2 = _interopRequireDefault(_moment);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; } /*jshint esversion: 6 */

/*
svglabel.js
===========
A module to reade SVG and spit out EZPL command for GoDex printers.
*/


var SvgLabel = function (_Label) {
   _inherits(SvgLabel, _Label);

   function SvgLabel(file, data, opts) {
      _classCallCheck(this, SvgLabel);

      var xml = _fs2.default.readFileSync(file, 'utf8');
      var temp = (0, _xmlParser2.default)(xml);

      var _this = _possibleConstructorReturn(this, (SvgLabel.__proto__ || Object.getPrototypeOf(SvgLabel)).call(this, {
         width: temp.root.attributes.width.replace("mm", ""),
         length: temp.root.attributes.height.replace("mm", "")
      }));

      _this.svg = temp;
      _this.data = data;
      _this.toDot = 8;
      return _this;
   }

   _createClass(SvgLabel, [{
      key: 'getPrintCommand',
      value: function getPrintCommand() {
         var result = "";
         _underscore2.default.each(this.svg.root.children, function (child) {
            var att = child.attributes;
            var name = child.name;

            // remove unit - mm
            att = _underscore2.default.mapObject(att, function (val, key) {
               return val.replace("mm", "");
            });

            if (name == "line") {
               this.svgLine(att);
            } else if (name == "rect") {
               this.svgRect(att);
            } else if (name == "text") {
               // Barcode
               if (child.content.indexOf("#BA#") >= 0) result += this.svgBarcode(child.content, att);
               // Date
               else if (child.content.indexOf("#DATE#") >= 0) {
                     result += this.svgText((0, _moment2.default)().format('DD-MMM-YY'), att);
                  }
                  // Normal Text
                  else result += this.svgText(child.content, att);
            }
         }, this);
         return _get(SvgLabel.prototype.__proto__ || Object.getPrototypeOf(SvgLabel.prototype), 'getPrintCommand', this).call(this);
      }

      /*
      * Convert SVG Line to EZPL Line
      */

   }, {
      key: 'svgLine',
      value: function svgLine(att) {
         if (att.x1 == att.x2 && att.y1 != att.y2) {
            var x = att.x * this.toDot,
                yStart = att.y1 * this.toDot,
                yEnd = att.y2 * this.toDot,
                tv = att['stroke-width'] * this.toDot;
            this.addLineVer(x, yStart, yEnd, tv);
         } else if (att.y1 == att.y2 && att.x1 != att.x2) {
            var xStart = att.x1 * this.toDot,
                xEnd = att.x2 * this.toDot,
                y = att.y1 * this.toDot,
                th = att['stroke-width'] * this.toDot;
            this.addLineHor(xStart, xEnd, y, th);
         } else return "";
      }
   }, {
      key: 'svgRect',
      value: function svgRect(att) {
         var xStart = att.x * this.toDot;
         var yStart = att.y * this.toDot;
         var width = att.width * this.toDot;
         var height = att.height * this.toDot;
         var t = Math.floor(att['stroke-width'] * this.toDot);
         this.addRect(xStart, yStart, width, height, t);
      }
   }, {
      key: 'svgBarcode',
      value: function svgBarcode(content, att) {
         var type = att['data-barcode-type'];
         var val = content;
         _underscore2.default.each(_underscore2.default.keys(this.data), function (key) {
            val = val.replace("#BA#-" + key, this.data[key]);
         }.bind(this));
         var x = att.x * this.toDot;
         var fs = att["font-size"] * 1 * this.toDot;
         var y = att.y * 1 * this.toDot - fs;
         this.addBarcode(type, x, y, 2, 4, fs, 0, 0, val);
      }
   }, {
      key: 'svgText',
      value: function svgText(content, att) {
         var val = content;
         _underscore2.default.each(_underscore2.default.keys(this.data), function (key) {
            val = val.replace("{" + key + "}", this.data[key]);
         }.bind(this));
         var fs = att["font-size"];
         var x = att.x * this.toDot;
         var y = (att.y - fs) * this.toDot;
         fs = Math.floor(fs * 3.75);
         this.addText(val, x, y, fs);
      }
   }]);

   return SvgLabel;
}(_label2.default);

exports.default = SvgLabel;